<div align="center">

# minitouch.py

python wrapper of minitouch, forked from [williamfzc/pyminitouch](https://github.com/williamfzc/pyminitouch) which licensed under [MIT](./LICENSE)

[![GitHub Actions Workflow Status](https://img.shields.io/github/actions/workflow/status/EvATive7/minitouch.py/package.yml)](https://github.com/EvATive7/minitouch.py/actions)
[![Python](https://img.shields.io/pypi/pyversions/minitouch.py)](https://badge.fury.io/py/minitouch.py)
[![PyPI version](https://badge.fury.io/py/minitouch.py.svg)](https://badge.fury.io/py/minitouch.py)
[![License](https://img.shields.io/github/license/EvATive7/minitouch.py.svg)](https://pypi.org/project/minitouch.py/)

</div>
